
function BovSys_run()

%main file
%This file has been written by
%Mohamed Omari, Zuse Institute Berlin, Takustr. 7, 14195 Berlin
%Version 2.0, September 2018

tic

            

%% Initial condition for the estrous model

y0 =      [ 0.667;      %'GnRhH'
            0.551;      % GnRhP
            0.316;      % FSHP
            0.395;      % FSHB
            1.;         % LHP 
            0.642;      % LHB
            1. ;        % Foll
            0.00506;    % PGF
            0.0;        % CL
            0.004;      % P4               
            0.89;       % E2
            0.826;      % INH 
            0;          % ENZ
            0.0183;     % OXT  
            0.35;       % IOF   
            0.48;       % IGF          
            15.5;       % INS 
            0.48;       % GLU 
            15e4;       % Fat  
            110;        % GLu_pr
            535;        % GLUstore
            105.];      % Glucagon
      
        
%% Names of State variables    

Ynames =  {'GnRhH'; 'GnRhP';'FSHP'; 'Blood-FSH'; 'LHP';  'Relative level of LH'; 'Follicle'; 'PGF';   'CL';    'Relative level of P4'...
            ;'Relative level of E2'; 'INH'; 'ENZ';  'Relative level of OXT';  'IOF'; 'Relative level of IGF-I';'Ins in mU/L'; 'Glu_{blood} in g/L'...
            ;'Fat in g'; 'Glucose in liver'; 'Glu_{store} in g';'Gluca in ng/L'};


%% Reading Parameters

        par=BovSys_para();
  
%% Read DMI and Milk data!

ObjDM = matfile('DM'); 
dm    = ObjDM.DMdataset(:,1);
ObjML = matfile('ML'); 
mlk   = ObjML.MLKdataset(:,2);

%% Simulation the lactating or non-lactating case (l/n) 

prompt = 'Do you want to simulate the lactating or non-lactating case? l/n: ';
str = input(prompt,'s');

%% Days to simulate the model
if str=='l'

    day = input('\n   Please insert how many days you want to simulate (max 270 days because data is limited): ');
    STEP=1/48;
    t=0:STEP:day;

elseif str=='n'
    
    day = input('\n   Please insert how many days you want to simulate: \n\n       For the normal non-lactating case: any number of days is possible \n       For the non-lactating case with accute dietary restriction:   at least 90 days \n       For the non-lactating case with chronic dietary restriction: at least 330 days: ');
    STEP=1/48;
    t=0:STEP:day;

end

%% Interpolating data to fit the the solver of ODE

at    = ObjML.MLKdataset(:,1)*7;    % Multiplying by 7 to convert from weeks to days
dm = interp1(at,dm, t);             % Interpolate the data set (at, dm) at times t
mlk = interp1(at,mlk, t);           % Interpolate the data set (at, dm) at times t
at = interp1(at,at, t);             % Interpolate the data set (at, dm) at times t


%% This are parameters to calculate glu_prod process 

pb= par(87);            
Tpb=par(88); 
epb=5;

%% Here the scenarios start: Simulation the lactating case (l) 



if  str == 'l';
    
    %%% Lactating Case
            
            y0(14)=2.5;          % We simulate lactating case with high oxytocin initial values
            
 
   %% Simulate with multiple fractions of glucose content

        ent = '\n      How many different fractions of glucose content in DMI (c0) do you want to simulate (insert 1 or 2 or ...)?:  ';
        numex  = input(ent);
        display('Please insert the different fractions in decreasing order now.')
        display('According to the paper, the numbers are recommended to be between 30 and 20.');
        
        fr= zeros(1, numex);
        
        for i = 1:numex
            fra.ent = sprintf('Insert value %d for glucose content in DMI (c0) in %% :  ', i);
            fr(i)= input(fra.ent)/100;
            
        end
        
        
        leg = cell(1,numex);
                
        for j=1:numex
            leg{j} = sprintf('%0.1f%%', fr(j)*100);
        end
                
  
        clf;  
        o=1;  

        for k = fr

                  c0 = k;

               %% This is the ODE solver for estrous model

                    odeopt = odeset('nonnegative',1:22) ;
                    [T,Y] = ode15s( @BovSys_Equa, t, y0, odeopt, par,str,at,dm,mlk,c0);

            %% Daily glucose production
            
            y_glu=Y(:,18);
            y_lv = Y(:,20);
            y_gluca= Y(:,22);
            Glu_pr = zeros(1,length(y_glu));
            
 

            for j = 1:length(y_glu)
                Glu_pr(j) = pb*y_lv(j)*y_gluca(j);
            end
            
            %% Figures
            
            X= Y(:, [10 16 6 11]);
            Xnames = Ynames([10 16 6 11]);

            figure(1) ;
            
            colorlist = char(':k', '-.b', '--g', '-r');

            for i= 1:length(Xnames)
                %colorlist = char('k', 'r', 'b', 'g','w','m','y','c');
                subplot(4,1,i) ;
                plot(T, X(:,i), colorlist(o), 'linewidth', 2);
                %set(gca,'color',[0.85 0.85 0.85])

                %title(Xnames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                ylabel(Xnames(i) ,'fontsize',24,'Fontname','Abyssinica SIL');
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                grid off;
            
                leg = cell(1,numex);

                for j=1:numex
                    leg{j} = sprintf('%0.1f%%', fr(j)*100);
                end
                
                h_legend = legend(leg);
                set(h_legend,'FontSize',20,'Location','SouthEast');
                legend('boxoff');
                
                ylabel(Xnames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                %ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                grid off;
                
                hold on

            end 
            
            
            figure(11) ;
            
                subplot(2,1,1) ;
                plot(T, Y(:,14), colorlist(o), 'linewidth', 2);

                title(Ynames(14),'fontsize',24,'Fontname','Abyssinica SIL');
                %xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                grid off;
            
                leg = cell(1,numex);

                for j=1:numex
                    leg{j} = sprintf('%0.1f%%', fr(j)*100);
                end
                
                h_legend = legend(leg);
                set(h_legend,'FontSize',10,'Location','SouthEast');
                legend('boxoff');
                
                title(Ynames(14),'fontsize',24,'Fontname','Abyssinica SIL');
                ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                grid off;
                
                hold on

             
            
            %% add oxytocin profile to the figure 
            
            subplot(2,1,2) ;
            
            ox=par(58)*exp(-par(60)*t.^2);

            plot(t,ox,'color', 'k','LineWidth',2);
            
            title('Oxytocin input','fontsize',24,'Fontname','Abyssinica SIL');
            ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
            xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
            set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
            grid off;
            
            

            %% Fig 2
            
            figure(2) ;
            
            Ymet=[18 21 22 17 19 20];
            %coulour = rand(1,3);
            coulour = char(':k', '-.b', '--g', '-r');
            %lt = char(':', '-.', '--', '-');

            for i= 1:5
%                 colorlist = char('k', 'r', 'b', 'g','w','m','y','c');

                subplot(2,3,i) ;

                plot(T, Y(:,Ymet(i)), coulour(o), 'linewidth', 2);
                                %set(gca,'color',[0.85 0.85 0.85])
               
                hold on
            
                leg = cell(1,numex);

                for j=1:numex
                    leg{j} = sprintf('%0.1f%%', fr(j)*100);
                end
               
                h_legend = legend(leg);
                set(h_legend,'fontsize',24,'Location','SouthEast');
                legend('boxoff');
                
                %title(Ynames(Ymet(i)),'fontsize',24,'Fontname','Abyssinica SIL');
                xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                ylabel(Ynames(Ymet(i)) ,'fontsize',24,'Fontname','Abyssinica SIL');
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                grid off;
                ax = gca;
                ax.XTick =0:50:250;


            end 

                subplot(2,3,6) ;
                hold on
                %title('Glucose production','fontsize',24,'Fontname','Abyssinica SIL');
                plot(T, Glu_pr, coulour(o), 'linewidth', 2);
                xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                ylabel('Glu_{prod} in g/d' ,'fontsize',24,'Fontname','Abyssinica SIL');
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                ax = gca;
                ax.XTick =0:50:250;
                box on

                
        %% Fig 3
      
         figure(o+2) ; 
         
            
            for i= 1:16

                    subplot(4,4,i) ;
                    plot(T, Y(:,i), colorlist(o), 'linewidth', 2);
                    hold on
                    title(Ynames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;                       
             
            end    

            

         
           %% Calculating processes of the model:

            y_glu=Y(:,18);
            y_glu_st = Y(:,21);
            y_lv = Y(:,20);
            y_ins = Y(:,17);
            y_fat  = Y(:,19);
            y_gluca=Y(:,22);

            glu_pool = zeros(1, length(y_glu));
            glu_feed_bl = zeros(1,length(y_glu));
            glu_feed_gng= zeros(1,length(y_glu));
            glu_lv_usage = zeros(1,length(y_glu));
            non_mammary_usage= zeros(1,length(y_glu));
            mammary_usage= zeros(1,length(y_glu));
            Fat_change= zeros(1,length(y_glu));
            Storage_change= zeros(1,length(y_glu));

            glu_prod = zeros(1,length(y_glu));       
            glu_bl_usage = zeros(1,length(y_glu));
            glu_bl_lv = zeros(1,length(y_glu));
            glu_lv_st = zeros(1,length(y_glu));
            glu_st_lv = zeros(1,length(y_glu));
            glu_fat_lv = zeros(1,length(y_glu));
            glu_lv_fat = zeros(1,length(y_glu));

            %% Calculating processes of the model:

            Glu_ini= interp1(at, dm, t);      
            Milk = interp1(at, mlk, t);      

            fat_gl = 9.3/4.1;  

            for j=1:length(y_glu)

                    glu_pool(j) = c0*Glu_ini(j);
                    
                    glu_feed_bl(j) =  par(77)*glu_pool(j);
                    
                    glu_feed_gng(j) =  (1-par(77))*glu_pool(j);

                    glu_prod(j) = par(87)*y_lv(j)*y_gluca(j);

                    glu_bl_usage(j) = par(93)*y_glu(j)^10/(y_glu(j)^10 + par(92)^10) + par(95)*Milk(j); 

                    glu_bl_lv(j) = par(88)*y_glu(j)^10/(y_glu(j)^10 + par(83)^10)*y_ins(j);

                    glu_lv_st(j) = par(82)*(1 - (y_glu_st(j)/1000))*(par(81)^2/(par(81)^2 + Milk(j)^2))*y_lv(j)*y_ins(j);

                    glu_st_lv(j) = par(80)*y_gluca(j)*(y_glu_st(j)^10/(y_glu_st(j)^10 + par(79)^10));

                    glu_fat_lv(j) = par(78)*((par(59)^10)/(y_glu_st(j)^10 + par(59)^10))*(y_fat(j)^1/(y_fat(j)^1 + par(98)^1))*y_gluca(j);

                    glu_lv_fat(j) = par(35)*(par(89)^1/(par(89)^1 + Milk(j)^1))*(y_glu_st(j)^10/(y_glu_st(j)^10 + par(90)^10))*y_lv(j)*y_ins(j);
                    
                    Storage_change(j)= glu_lv_st(j) - glu_st_lv(j);
                    
                    Fat_change(j)= glu_lv_fat(j)*fat_gl - glu_fat_lv(j);
   
                    glu_lv_usage(j) = par(94)*y_lv(j);
                    
                    non_mammary_usage(j) = par(93)*(y_glu(j)^10)/(y_glu(j)^10 + par(92)^10); 
                    
                    mammary_usage(j) =  par(95)*Milk(j);

            end
            
            Fat_change_bar= zeros(1,day);
            for h=1:day
                m=1+(1/STEP)*(h-1);
                d = (1/STEP)*h;
                % calculating are under curve of the bar: sum f(xi)*((b - a)/N)   
                Fat_change_bar(h)= sum( Fat_change(m:d)/(1/STEP));
            end


            %% Plotting processes:  Fig 16 in the manuscript

            figure(2000+o) ;


            subplot(3,3,1) ;
            plot(T,glu_feed_bl, coulour(o), 'linewidth', 2);
            ylabel('glu_{feed-bl} in g/d','fontsize',24);
            set(gca,'fontsize',24)   

            subplot(3,3,2) ;
            plot(T,glu_feed_gng, coulour(o), 'linewidth', 2);
            ylabel('glu_{feed-gng} in g/d','fontsize',24);
            set(gca,'fontsize',24)

            subplot(3,3,3) ;
            plot(T,glu_prod, coulour(o), 'linewidth', 2);
            ylabel('glu_{prod} in g/d','fontsize',24);
            set(gca,'fontsize',24)
            
            subplot(3,3,4) ;
            plot(T,non_mammary_usage, coulour(o), 'linewidth', 2);
            ylabel({'non-mammary'; 'usage in g/d'},'fontsize',24);
            set(gca,'fontsize',24)

            subplot(3,3,5) ;
            plot(T,glu_lv_usage, coulour(o), 'linewidth', 2);
            ylabel('glu_{lv-usage} in g/d','fontsize',24);
            set(gca,'fontsize',24)
            
            subplot(3,3,6) ;
            plot(T, mammary_usage, coulour(o), 'linewidth', 2);
            ylabel({'mammary usage'; 'in g/d'},'fontsize',24);
            set(gca,'fontsize',24)
            
            subplot(3,3,7) ;
            plot(T,glu_bl_usage, coulour(o), 'linewidth', 2);
            ylabel('glu_{bl-usage} in g/d','fontsize',24);
            set(gca,'fontsize',24)
            xlabel('days','fontsize',24);
            
            subplot(3,3,8) ;
            plot(T,Storage_change, coulour(o), 'linewidth', 2);
            ylabel({'Change in glucose'; 'storage in g/d'},'fontsize',24);
            set(gca,'fontsize',24)
            xlabel('days','fontsize',24);
            
            subplot(3,3,9) ;
            plot(T,Fat_change, coulour(o), 'linewidth', 2);
            ylabel('Change in fat in g/d','fontsize',24);
            set(gca,'fontsize',24)
            xlabel('days','fontsize',24);
            legend(sprintf('c_{0}=%0.1f%%', fr(o)*100));
            
            
            %% Fat change as indicator of energy balance:   bar plot  
            figure(4001);   
            subplot(4,1,o);
            
                bar(1:day,Fat_change_bar)
                ylabel('Change in fat in g/d','fontsize',24);
                set(gca,'fontsize',24)
                xlabel('days','fontsize',24);     
                legend(sprintf('c_{0}=%0.1f%%', fr(o)*100));

                

            %% Fat change as indicator of energy balance:   line plot  
            figure(4000) ;
            plot(T,Fat_change, coulour(o), 'linewidth', 2);
            hold on
            ylabel('Fat change in g/d','fontsize',24);
            set(gca,'fontsize',24)
            xlabel('days','fontsize',24);
           
            o=o+1;    
            
            %% legend
            
                leg = cell(1,numex);

                for j=1:numex
                    leg{j} = sprintf('%0.1f%%', fr(j)*100);
                end
               
                h_legend = legend(leg);
                set(h_legend,'fontsize',24,'Location','SouthEast');
                legend('boxoff');
        end
        
        
        
        
        
        
             %% Fitting the model to data:   Fig 13 in the manuscript
              
              Glufra=35:-2.5:17.5;
              Gluall=unique([Glufra, 15:40]);
              Ovtime=[40 41 42 44 50 85 148 260];
              
              %% Exponential curve
              fun = @(x,y) x(1).*exp(-x(2).*(y)) + x(3); 

              x0=[400 0.00005 25];

              [out,~,~,~,~] = lsqcurvefit(fun,x0,Glufra,Ovtime);
              
         
              figure(13)    
              plot(Gluall,fun(out,Gluall),'k',Glufra,Ovtime,'ro','MarkerFaceColor','r', 'linewidth', 2);
                xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                ylabel('Time (day) of first ovulation after calving' ,'fontsize',24,'Fontname','Abyssinica SIL');
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                grid off;
        

            
        
    
  
    
    disp('------------------------------------------------------');
    fprintf('\n');
   
    
%% Here the scenario of non-lactating case (n)

elseif str == 'n';
    
    %%
    %%%% Non-Lactating Case

    disp('---------------------');
    
    %% Choose if you want to simulate the standard fraction of glucose content
    
    prompt = 'Do you want to simulate the model with standard DMI i.e. 11700 g/d? If so, insert y. \nIf not (e.g., in case of dietary restrictions), then insert n : '; 
    dummy = input(prompt,'s');
    
    %% Simulation with non-standard fraction of glucose content i.e # 11700 g/d

    if dummy == 'n';
        
        
        prompt2 = '\n   Please choose between different simulation scenarios: \n       Different amounts of DMI (insert n),\n       Acute dietary restriction (insert a),\n       Chronic dietary restriction (insert c): '; 
        dummy2 = input(prompt2,'s');
        
        
        if dummy2 == 'n';
        
            c0 = 0.08;

            %%% Simulate WITHOUT standard feeding (11700 g/d) 

                mlk = linspace(0,0,numel(t));
                p3 = 'How much DMI (in %) you want to simulate e.g. 0 to 200? (the standard DMI is 100%):  ';
                percent = input(p3);
                dmfast1 = percent/100; 

                dm  = linspace(dmfast1*11700,dmfast1*11700,numel(t)); 
                at  = linspace(0,day,length(dm));

                
                   %% This is the ODE solver for estrous model


                            odeopt = odeset('nonnegative',1:22);
                            [T,Y] = ode15s( @BovSys_Equa, t, y0, odeopt, par,str,at,dm,mlk,c0);
                         
            

                
             %% Figures
             
             
                %clf;
                figure(1) ; 

                
                for i= 1:16

                        subplot(5,4,i) ;
                        plot(T, Y(:,i),   'linewidth', 2);

                        title(Ynames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                        xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                        ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                        set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                        grid off;
        

                end
                
                
            %% Daily glucose production
            
            y_glu=Y(:,18);
            y_lv = Y(:,20);
            y_gluca=Y(:,22);
            Glu_pr = zeros(1,length(y_glu));

            for j = 1:length(y_glu)
                Glu_pr(j) = pb*y_lv(j)*y_gluca(j);
            end
            

            
            Glu_from_DMI_iter= zeros(1,day);
            
            for h=1:(day)
                m=1+(1/STEP)*(h-1);
                d = (1/STEP)*h;
                Glu_from_DMI_iter(h) = sum( Glu_pr(m:d)/(1/STEP));    %sum f(xi)*((b - a)/N)
            end

            
                figure(2)
                %hold on
                
                for i= 17:21

                        subplot1=subplot(3,3,i-16) ;
                        hold on

                        plot(T, Y(:,i),   'linewidth', 2);
                       
                        hold on

                        title(Ynames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                        xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                        ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                        set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                        grid off;

                end

                subplot(3,3,6) ;
                hold on
                title('Glucagon','fontsize',24,'Fontname','Abyssinica SIL');
                plot(T, Y(:,22),   'linewidth', 2);
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                box(subplot1,'on');
                
                
                subplot(3,3,7) ;
                hold on
                coulour = rand(1,3);
                title('Glucose production','fontsize',24,'Fontname','Abyssinica SIL');
                bar(1:day,Glu_from_DMI_iter,'FaceColor',coulour,'EdgeColor', coulour, 'linewidth', 2)
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                box(subplot1,'on');


                
        %% Acute dietary scenario   
        
        elseif dummy2 == 'a'

        %fe = 'fraction of Glucose in DMI?: ';
        %fed = input(fe);
            c0 = 0.08; 
    
        %%% Simulate WITHOUT standad feeding (11700 g/d) 
        
            mlk = linspace(0,0,numel(t));
            dm1 = 11700;
            diet_start = 46;   
            diet_interval = 15;
            dmfast1 = 0.33;  
            dm2 = 11700;
            delay = 0;
            dm  = [linspace(dm1,dm1, diet_start*(1/STEP)), linspace(dmfast1*11700,dmfast1*11700, diet_interval*(1/STEP)),linspace(   dmfast1*11700  ,   dm2,   delay*(1/STEP) ),linspace(   dm2   ,   dm2,   (numel(t) -delay*(1/STEP) - diet_start*(1/STEP) - diet_interval*(1/STEP) ))];
            at  = linspace(0,day,length(dm));
            
               %% This is the ODE solver for estrous model


                            odeopt = odeset('nonnegative',1:22) ;
                            [T,Y] = ode15s( @BovSys_Equa, t, y0, odeopt, par,str,at,dm,mlk,c0);
                         
            
            %% Daily glucose production
            
            y_glu=Y(:,18);
            y_lv = Y(:,20);
            Glu_pr = zeros(1,length(y_glu));


            for j = 1:length(y_glu)
                Glu_pr(j) = pb*y_lv(j)*(Tpb^epb/(Tpb^epb + y_glu(j)^epb));
            end

            
            Glu_from_DMI_iter= zeros(1,day);
            
            for h=1:(day)
                m=1+(1/STEP)*(h-1);
                d = (1/STEP)*h;
                Glu_from_DMI_iter(h) = sum( Glu_pr(m:d)/(1/STEP));    %sum f(xi)*((b - a)/N)
            end
            
            %% Figures
            
            %clf;
            figure(1) ; 
                        hold on

            for i= 1:16

                    subplot(4,4,i) ;
                    hold on

                    plot(T, Y(:,i),   'linewidth', 2);

                    title(Ynames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;

                    
                    yL = get(gca,'YLim');
                    line([diet_start diet_start],yL,'Color','r','LineWidth',2);
                    period = diet_start + diet_interval;
                    line([period period],yL,'Color','r','LineWidth',2);
                    %line([20*3 20*3],yL,  'LineStyle', '--', 'color', 'k', 'LineWidth',2);
                    
                    td1=54; % or 54 53.5 53.6             %32 four waves  % 30 just two waves 
                    td2 = td1 + 11;
                    
                    line([td1 td1],yL,  'LineStyle', '--', 'color', 'k', 'LineWidth',2);
                    line([td2 td2],yL,  'LineStyle', '--', 'color', 'k', 'LineWidth',2);



            end
            
            %% Fig 2

 
            figure(3) ; 
            
            X=[Y(:,[6 16 4]) Y(:,17) Y(:,11) Y(:,21) Y(:,10) Y(:,19)];           
            Xnames=[Ynames([6 16 4]); Ynames(17); Ynames(11); Ynames(21); Ynames(10); Ynames(19)];
            
            for i= 1:length(Xnames)

                    subplot(4,2,i) ;
                    plot(T, X(:,i),   'linewidth', 2);
                    
                    title(Xnames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;

                    
                    yL = get(gca,'YLim');
                    line([diet_start diet_start],yL,'Color','r','LineWidth',2);
                    period = diet_start + diet_interval;
                    line([period period],yL,'Color','r','LineWidth',2);
                    %line([20*3 20*3],yL,  'color', 'k', 'LineWidth',2);
%                                             xlim([0 90])


            end    
            
            
            
        %% Chronic dietary scenario    
            
        elseif dummy2 == 'c'

        %fe = 'fraction of Glucose in DMI?: ';
        %fed = input(fe);
            c0 = 0.08;
   
        %%% Simulate WITHOUT standad feeding (11700 g/d) 

            dm1 = 11700;
 
            diet_start = 45.;

            diet_interval = 30*7;

            dmfast1 = 0.58;  % 58% DMI
            
            dm2 = 11700*1.6;   %0.7  
            diet_after_rest= 7*10;
            
            period3 = diet_start + diet_interval + 7*10;
            
            dm  = [linspace(dm1,dm1, diet_start*(1/STEP)), ...
                   linspace(dmfast1*11700,dmfast1*11700, diet_interval*(1/STEP)),...
                   linspace(dm2,dm2, diet_after_rest*(1/STEP)), ...
                   linspace(dm1,dm1,   (numel(t)  - diet_start*(1/STEP) - diet_interval*(1/STEP) - diet_after_rest*(1/STEP) ))];
            
            while day < period3
                disp('Warning!!!:  time period is short');
                sprintf('Period of time must be more than days %d', period3)
                
                day = input('try again:');
                
                STEP=1/(1/STEP);
                t=0:STEP:day;
                dm  = [linspace(dm1,dm1, diet_start*(1/STEP)), ...
                   linspace(dmfast1*11700,dmfast1*11700, diet_interval*(1/STEP)),...
                   linspace(dm2,dm2, diet_after_rest*(1/STEP)), ...
                   linspace(dm1,dm1,   (numel(t)  - diet_start*(1/STEP) - diet_interval*(1/STEP) - diet_after_rest*(1/STEP) ))];
            
            end
            
            at  = linspace(0,day,length(dm));
            mlk = linspace(0,0,length(dm));

               %% This is the ODE solver for estrous model


                            odeopt = odeset('nonnegative',1:22) ;
                            [T,Y] = ode15s( @BovSys_Equa, t, y0, odeopt, par,str,at,dm,mlk,c0);
                         
            
            %% Daily glucose production
            
            y_glu=Y(:,18);
            y_lv = Y(:,20);
            Glu_pr = zeros(1,length(y_glu));
            


            for j = 1:length(y_glu)
                Glu_pr(j) = pb*y_lv(j)*(Tpb^epb/(Tpb^epb + y_glu(j)^epb));
            end

            
            Glu_from_DMI_iter= zeros(1,day);
            
            for h=1:(day)
                m=1+(1/STEP)*(h-1);
                d = (1/STEP)*h;
                Glu_from_DMI_iter(h) = sum( Glu_pr(m:d)/(1/STEP));    %sum f(xi)*((b - a)/N)
            end
                            
            %% Figures
            
            clf;
            figure(1) ; 
            
            for i= 1:16

                    subplot(4,4,i) ;
                    plot(T, Y(:,i),   'linewidth', 2);
                    
                    title(Ynames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;
    
                    
                    yL = get(gca,'YLim');
                    
                    period0 = diet_start + 20*7;
                    period2 = diet_start + diet_interval;
                    period3 = diet_start + (diet_interval + 7*10);
                    
                    line([diet_start diet_start],yL,'Color','r','LineWidth',2);
                    line([period0 period0],yL,'Color','k','LineWidth',2);
                    line([period2 period2],yL,'Color','r','LineWidth',2);
                    line([period3 period3],yL,'Color','k','LineWidth',2);
                    

            end
            
            %% Fig 2
            
            figure(3) ; 
            
            
            X=[Y(:,[6 16 4]) Y(:,17) Y(:,11) Y(:,21) Y(:,10) Y(:,19)];         
            Xnames=[Ynames([6 16 4]); Ynames(17); Ynames(11); Ynames(21); Ynames(10); Ynames(19)];
            
            for i= 1:length(Xnames)

                    subplot(4,2,i) ;
                    plot(T, X(:,i),   'linewidth', 2);
                    
                    title(Xnames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;
    

              yL = get(gca,'YLim');
                    line([diet_start diet_start],yL,'Color','r','LineWidth',2);
                    period2 = diet_start + diet_interval;
                    line([period2 period2],yL,'Color','r','LineWidth',2);
                    xlim([0 320])

                    
            end
    

        end
        
        
  %% Simulate with standad feeding (11700 g/d) 

        
    elseif  dummy == 'y';
        
        %%% Simulate with standad feeding (11700 g/d) 
            
            mlk = linspace(0,0,numel(t));
            dm  = linspace(11700,11700,numel(t));
            at =  linspace(0,day, numel(t));
            
            entry = '\n       You can either simulate the model with the standard glucose content in DMI, i.e., c0=8% (insert n) \n       OR with different values (c0) for glucose content in DMI (insert y): ';
            im = input(entry,'s');

            if im == 'n';

                %%% Simulate WITHOUT multiple fractions of glucose content

                c0 = 0.08;
                
               %% This is the ODE solver for estrous model

                    odeopt = odeset('nonnegative',1:22) ;
                    [T,Y] = ode15s( @BovSys_Equa, t, y0, odeopt, par,str,at,dm,mlk,c0);
                   
                    


     
            %% Daily glucose production
            
            y_glu=Y(:,18);
            y_lv = Y(:,20);
            y_gluca=Y(:,22);            
            Glu_pr = zeros(1,length(y_glu));
                      
            for j = 1:length(y_glu)
                Glu_pr(j) = pb*y_lv(j)*y_gluca(j);
            end

            Glu_from_DMI_iter= zeros(1,day);
            
            for h=1:(day)
                m=1+(1/STEP)*(h-1);
                d = (1/STEP)*h;
                Glu_from_DMI_iter(h) = sum( Glu_pr(m:d)/(1/STEP));    %sum f(xi)*((b - a)/N)
            end
             

               
            %% Figures   
                
                %clf;
                
                %data loading
                load('Data_P4_Hol.mat')
                load('Data_IGF_Hol.mat')


                figure(1) ; 
                hold on
                
                for i= 1:16
 
                    subplot(4,4,i) ;
                    
                    plot(T, Y(:,i),   'linewidth', 2);
                    %xlim([100 110])

                    title(Ynames(i),'fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level','fontsize',24,'Fontname','Abyssinica SIL');
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;


                end
     
                
                figure(2)
                %clf
                
                sft=18;
                subplot(2,2,2) ;
                    plot(T, Y(:,16),   'linewidth', 2);
                    hold on
                    igfx=Data_IGF_Hol(1:8,1)+sft;
                    yIGFdata=Data_IGF_Hol(1:8,2);
                    igfy=yIGFdata/300;
                    plot(igfx, igfy,'ro','MarkerFaceColor','r')
                    %title(Ynames(16),'fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level of IGF-1','fontsize',24,'Fontname','Abyssinica SIL');
                    text(0.01,0.9,'B','Units','normalized','fontsize',24);
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;
                    
                subplot(2,2,1) ;
                    plot(T, Y(:,10),   'linewidth', 2);
                    hold on
                    p4x=Data_P4_Hol(1:8,1)+sft;
                    yP4data=Data_P4_Hol(1:8,2);
                    p4y=0.3*yP4data;
                    plot(p4x, p4y,'ro','MarkerFaceColor','r')
                    %title(Ynames(10),'fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days','fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level of P4','fontsize',24,'Fontname','Abyssinica SIL');
                    text(0.01,0.9,'A','Units','normalized','fontsize',24);
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;
                    
               
                figure(3) ; 
                %clf;
                
                Ymet=17:21;
               
                
                for i= 1:5

                    subplot(3,3,i) ;
                    hold on
                    plot(T, Y(:,Ymet(i)),   'linewidth', 2);
                    %xlim([250 300])

                    title(Ynames(Ymet(i)),'fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level','fontsize',24,'Fontname','Abyssinica SIL');
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;

                    

                end
                
                subplot(3,3,7) ;
                    hold on
                    plot(T, Y(:,22),   'linewidth', 2);
                    %xlim([250 300])

                    title('Glucagon','fontsize',24,'Fontname','Abyssinica SIL');
                    xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                    ylabel('Relative level','fontsize',24,'Fontname','Abyssinica SIL');
                    set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                    grid off;
                
                
                subplot(3,3,6) ;
                hold on
                title('Glucose production','fontsize',24,'Fontname','Abyssinica SIL');
                bar(1:day,Glu_from_DMI_iter, 'linewidth', 2)
                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
               



%% Plotting processes 

                
                
 
            elseif im == 'y'; 
                %%n
                % 
                %   for x = 1:10
                %       disp(x)
                %   end
                % 
                %%% Simulate with multiple fractions of glucose content
                
                ent = '\n       How many different values for glucose content in DMI do you want to simulate? (insert 1 or 2 ...): ';
                numex  = input(ent);
            
                display('Please enter the values for glucose content in DMI (c0) in decreasing order now.')
                display('According to the paper, values are recommended to be in the range from 16 to 4 (the standard value is 8%%).');
                
                fr= zeros(1, numex);
        
                for i = 1:numex
                    fra.ent = sprintf('\n          Insert %dth value for glucose content in DMI (c0) in %% :  ', i);
                    fr(i)= input(fra.ent)/100;
            
                end
            
  
                
                        clf;
                        
                        o = 1;
                        colorlist = char('k', 'b', 'r', 'g','c','m','y','w');
                        colorl = char('k', 'b', 'r', 'g');

                        
                        for k = fr

                            c0 = k;
                            
                              %% This is the ODE solver for estrous model

                               odeopt = odeset('nonnegative',1:22) ;
                               [T,Y] = ode15s( @BovSys_Equa, t, y0, odeopt, par,str,at,dm,mlk,c0);

                            %% Daily glucose production

                            y_glu=Y(:,18);
                            y_lv = Y(:,20);
                            y_gluca=Y(:,22);
                            Glu_pr = zeros(1,length(y_glu));

                            for j = 1:length(y_glu)
                                Glu_pr(j) = pb*y_lv(j)*y_gluca(j);
                            end


%                             Glu_from_DMI_iter= zeros(1,day);
% 
%                             for h=1:(day)
%                                 m=1+(1/STEP)*(h-1);
%                                 d = (1/STEP)*h;
%                                 Glu_from_DMI_iter(h) = sum( Glu_pr(m:d)/(1/STEP));    %sum f(xi)*((b - a)/N)
%                             end

                             %% Figures


                                            figure(1) ; 

                                            Ymet=[18 21 22 17 19 20];

                                            for i= 1:5

                                                subplot(2,3,i) ;
                                                plot(T, Y(:,Ymet(i)),colorlist(o),'linewidth', 2);
                                                hold on
                                                %title(Ynames(Ymet(i)),'fontsize',24,'Fontname','Abyssinica SIL');
                                                xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                                                ylabel(Ynames(Ymet(i)),'fontsize',24,'Fontname','Abyssinica SIL');
                                                set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                                                grid off;
                                                ax = gca;
                                                ax.XTick =0:10:50;



                                            end
                                            
                                             subplot(2,3,6) ;
                                             hold on
                                             plot(T,Glu_pr,'color',colorlist(o), 'linewidth', 2)
                                             xlabel('days' ,'fontsize',24,'Fontname','Abyssinica SIL');
                                             ylabel('Glu_{prod}','fontsize',24,'Fontname','Abyssinica SIL');
                                             set(gca,'fontsize',24,'Fontname','Abyssinica SIL');
                                             ax = gca;
                                             ax.XTick =0:10:50;
                                             box on
                                            

                                            leg = cell(1,numex);

                                            for j=1:numex
                                                leg{j} = sprintf('%0.1f%%', fr(j)*100);
                                            end



                                            h_legend = legend(leg);
                                            set(h_legend, 'FontSize',20,'Location','eastoutside');
                                            legend('boxoff');
                                            hold on

                                            xlabel('days','fontsize',24);                                         
                                            
           %% Calculating processes of the model:

            y_glu=Y(:,18);
            y_glu_st = Y(:,21);
            y_lv = Y(:,20);
            y_ins = Y(:,17);
            y_fat  = Y(:,19);
            y_gluca=Y(:,22);

            glu_pool = zeros(1, length(y_glu));
            glu_feed_bl = zeros(1,length(y_glu));
            glu_feed_gng= zeros(1,length(y_glu));
            glu_lv_usage = zeros(1,length(y_glu));
            non_mammary_usage= zeros(1,length(y_glu));
            mammary_usage= zeros(1,length(y_glu));
            Fat_change= zeros(1,length(y_glu));
            Storage_change= zeros(1,length(y_glu));

            glu_prod = zeros(1,length(y_glu));       
            glu_bl_usage = zeros(1,length(y_glu));
            glu_bl_lv = zeros(1,length(y_glu));
            glu_lv_st = zeros(1,length(y_glu));
            glu_st_lv = zeros(1,length(y_glu));
            glu_fat_lv = zeros(1,length(y_glu));
            glu_lv_fat = zeros(1,length(y_glu));

            %% Calculating processes of the model:

            Glu_ini= interp1(at, dm, t);      
            Milk = interp1(at, mlk, t);      

            fat_gl = 9.3/4.1;  

            for j=1:length(y_glu)

                    glu_pool(j) = c0*Glu_ini(j);
                    
                    glu_feed_bl(j) =  par(77)*glu_pool(j);
                    
                    glu_feed_gng(j) =  (1-par(77))*glu_pool(j);

                    glu_prod(j) = par(87)*y_lv(j)*y_gluca(j);

                    glu_bl_usage(j) = par(93)*y_glu(j)^10/(y_glu(j)^10 + par(92)^10) + par(95)*Milk(j); 

                    glu_bl_lv(j) = par(88)*y_glu(j)^10/(y_glu(j)^10 + par(83)^10)*y_ins(j);

                    glu_lv_st(j) = par(82)*(1 - (y_glu_st(j)/1000))*(par(81)^2/(par(81)^2 + Milk(j)^2))*y_lv(j)*y_ins(j);

                    glu_st_lv(j) = par(80)*y_gluca(j)*(y_glu_st(j)^10/(y_glu_st(j)^10 + par(79)^10));

                    glu_fat_lv(j) = par(78)*((par(59)^10)/(y_glu_st(j)^10 + par(59)^10))*(y_fat(j)^1/(y_fat(j)^1 + par(98)^1))*y_gluca(j);

                    glu_lv_fat(j) = par(35)*(par(89)^1/(par(89)^1 + Milk(j)^1))*(y_glu_st(j)^10/(y_glu_st(j)^10 + par(90)^10))*y_lv(j)*y_ins(j);
                    
                    Storage_change(j)= glu_lv_st(j) - glu_st_lv(j);
                    
                    Fat_change(j)= glu_lv_fat(j)*fat_gl - glu_fat_lv(j);
   
                    glu_lv_usage(j) = par(94)*y_lv(j);
                    
                    non_mammary_usage(j) = par(93)*(y_glu(j)^10)/(y_glu(j)^10 + par(92)^10); 
                    
                    mammary_usage(j) =  par(95)*Milk(j);

            end


                           non_mammary_usage_bar= zeros(1,day);
                           glu_bl_lv_bar= zeros(1,day);
                           glu_feed_gng_bar= zeros(1,day);
                           glu_feed_bl_bar= zeros(1,day);
                           glu_lv_usage_bar= zeros(1,day);
                           glu_prod_bar= zeros(1,day);
                           glu_bl_usage_bar= zeros(1,day);
                           Fat_change_bar= zeros(1,day);
                           Storage_change_bar= zeros(1,day);


                        for h=1:day
                            m=1+(1/STEP)*(h-1);
                            d = (1/STEP)*h;
                           non_mammary_usage_bar(h) = sum( non_mammary_usage(m:d)/(1/STEP));    %sum f(xi)*((b - a)/N)
                           glu_bl_lv_bar(h) = sum( glu_bl_lv(m:d)/(1/STEP));        %sum f(xi)*((b - a)/N)   
                           glu_feed_gng_bar(h)= sum( glu_feed_gng(m:d)/(1/STEP));
                           glu_feed_bl_bar(h) = sum( glu_feed_bl(m:d)/(1/STEP));
                           glu_lv_usage_bar(h) = sum( glu_lv_usage(m:d)/(1/STEP));
                           glu_prod_bar(h)= sum( glu_prod(m:d)/(1/STEP));
                           glu_bl_usage_bar(h)= sum( glu_bl_usage(m:d)/(1/STEP));
                           Fat_change_bar(h)= sum( Fat_change(m:d)/(1/STEP));
                           Storage_change_bar(h)= sum( Storage_change(m:d)/(1/STEP));

                        end



            %% Plotting processes 

            figure(2000+o) ;
            
            subplot(3,3,1) ;
            bar(1:day,glu_feed_bl_bar,'FaceColor',colorl(o),'EdgeColor',colorl(o), 'linewidth', 2)
            ylabel('glu_{feed-bl} in g/d','fontsize',24);
            set(gca,'fontsize',24)
            legend(sprintf('c_{0}=%0.1f%%', fr(o)*100));
            
            subplot(3,3,2) ;
            bar(1:day,glu_feed_gng_bar,'FaceColor',colorl(o),'EdgeColor',colorl(o), 'linewidth', 2)
            ylabel('glu_{bl-gng}','fontsize',24);
            set(gca,'fontsize',24)

            subplot(3,3,3) ;
            bar(1:day,glu_prod_bar,'FaceColor',colorl(o),'EdgeColor',colorl(o), 'linewidth', 2)
            ylabel('glu_{prod} in g/d','fontsize',24);
            set(gca,'fontsize',24)
            
            subplot(3,3,4) ;
            bar(1:day,non_mammary_usage_bar,'FaceColor',colorl(o),'EdgeColor',colorl(o), 'linewidth', 2)
            ylabel({'non-mammary'; 'usage in g/d'},'fontsize',24);
            set(gca,'fontsize',24)
            
            subplot(3,3,5) ;
            bar(1:day,glu_lv_usage_bar,'FaceColor',colorl(o),'EdgeColor',colorl(o), 'linewidth', 2)
            ylabel('glu_{lv-usage} in g/d','fontsize',24);
            set(gca,'fontsize',24)
            
            subplot(3,3,6) ;
            bar(1:day,glu_bl_lv_bar,'FaceColor',colorl(o),'EdgeColor',colorl(o), 'linewidth', 2)
            ylabel({'glu_{bl-lv} in g/d'},'fontsize',24);
            set(gca,'fontsize',24)
            
            subplot(3,3,7) ;
            bar(1:day,glu_bl_usage_bar,'FaceColor',colorl(o),'EdgeColor',colorl(o), 'linewidth', 2)
            ylabel('glu_{bl-usage} in g/d','fontsize',24);
            set(gca,'fontsize',24)
            xlabel('days','fontsize',24);
            
            subplot(3,3,8) ;
            bar(1:day,Storage_change_bar,'FaceColor',colorl(o),'EdgeColor',colorl(o), 'linewidth', 2)
            ylabel({'Change in glucose'; 'storage in g/d'},'fontsize',24);
            set(gca,'fontsize',24)
            xlabel('days','fontsize',24);
            
            subplot(3,3,9) ;
            bar(1:day,Fat_change_bar,'FaceColor',colorl(o),'EdgeColor',colorl(o), 'linewidth', 2)
            ylabel('Change in fat in g/d','fontsize',24);
            set(gca,'fontsize',24)
            xlabel('days','fontsize',24);
            
            o=o+1;


                     
                        end         
    
    

    end
    
    
    
    

    
    

end

end


